@@ -80,7 +80,7 @@
 
 #ifdef ENABLE_CONTENTVIEWS
 #include <CalendarSupport/IncidenceViewer>
-#include <messageviewer/viewer.h>
+#include <MessageViewer/Viewer>
 #include <Akonadi/Contact/ContactViewer>
 #include <Akonadi/Contact/ContactGroupViewer>
 #endif
@@ -378,33 +378,31 @@ void BrowserWidget::setItem(const Akonadi::Item &item)
     contentUi.size->setText(QString::number(item.size()));
     contentUi.modificationtime->setText(item.modificationTime().toString() + QStringLiteral(" UTC"));
     QStringList flags;
-    foreach (const Item::Flag &f, item.flags()) {
+    const auto itemFlags = item.flags();
+    for (const Item::Flag &f : itemFlags) {
         flags << QString::fromUtf8(f);
     }
     contentUi.flags->setItems(flags);
 
     QStringList tags;
-    foreach (const Tag &tag, item.tags()) {
+    const auto itemTags = item.tags();
+    for (const Tag &tag : itemTags) {
         tags << QLatin1String(tag.gid());
     }
     contentUi.tags->setItems(tags);
 
     Attribute::List list = item.attributes();
     delete mAttrModel;
-    mAttrModel = new QStandardItemModel(list.count(), 2);
-    QStringList labels;
-    labels << QStringLiteral("Attribute") << QStringLiteral("Value");
+    mAttrModel = new QStandardItemModel();
+    QStringList labels{QStringLiteral("Attribute"), QStringLiteral("Value")};
     mAttrModel->setHorizontalHeaderLabels(labels);
-    for (int i = 0; i < list.count(); ++i) {
-        QModelIndex index = mAttrModel->index(i, 0);
-        Q_ASSERT(index.isValid());
-        mAttrModel->setData(index, QString::fromLatin1(list[i]->type()));
-        index = mAttrModel->index(i, 1);
-        Q_ASSERT(index.isValid());
-        mAttrModel->setData(index, QString::fromLatin1(list[i]->serialized()));
-        mAttrModel->itemFromIndex(index)->setFlags(Qt::ItemIsEditable | mAttrModel->flags(index));
+    for (const auto *attr : list) {
+        auto type = new QStandardItem(QString::fromLatin1(attr->type()));
+        type->setEditable(false);
+        mAttrModel->appendRow({type, new QStandardItem(QString::fromLatin1(attr->serialized()))});
     }
     contentUi.attrView->setModel(mAttrModel);
+    connect(mAttrModel, &QStandardItemModel::itemChanged, this, &BrowserWidget::contentViewChanged);
 
     if (mMonitor) {
         mMonitor->deleteLater();    // might be the one calling us
@@ -444,16 +442,20 @@ void BrowserWidget::save()
     Item item = mCurrentItem;
     item.setRemoteId(contentUi.remoteId->text());
     item.setGid(contentUi.gid->text());
-    foreach (const Item::Flag &f, mCurrentItem.flags()) {
+    const auto currentItemFlags = mCurrentItem.flags();
+    for (const Item::Flag &f : currentItemFlags) {
         item.clearFlag(f);
     }
-    foreach (const QString &s, contentUi.flags->items()) {
+    const auto contentUiItemFlags = contentUi.flags->items();
+    for (const QString &s : contentUiItemFlags) {
         item.setFlag(s.toUtf8());
     }
-    foreach (const Tag &tag, mCurrentItem.tags()) {
+    const auto contentUiItemTags = mCurrentItem.tags();
+    for (const Tag &tag : contentUiItemTags) {
         item.clearTag(tag);
     }
-    foreach (const QString &s, contentUi.tags->items()) {
+    const auto contentUiTagsItems = contentUi.tags->items();
+    for (const QString &s : contentUiTagsItems) {
         Tag tag;
         tag.setGid(s.toLatin1());
         item.setTag(tag);
