@@ -39,7 +39,7 @@ class LIBAKONADICONSOLE_EXPORT InstanceSelector : public QDialog
 {
     Q_OBJECT
 public:
-    explicit InstanceSelector(const QString &remoteHost, QWidget *parent = nullptr, Qt::WindowFlags flags = nullptr);
+    explicit InstanceSelector(const QString &remoteHost, QWidget *parent = nullptr, Qt::WindowFlags flags = {});
     virtual ~InstanceSelector();
 
 private Q_SLOTS:
