@@ -145,7 +145,7 @@ void Logging::saveToFile()
     QTextStream stream(&file);
     for (int row = 0, cnt = mModel->rowCount(); row < cnt; ++row) {
         const auto msg = mModel->data(mModel->index(row, 0), LoggingModel::MessageRole).value<LoggingModel::Message>();
-        stream << "[" << QDateTime::fromTime_t(msg.timestamp).toString(Qt::ISODateWithMs) << "] "
+        stream << "[" << QDateTime::fromMSecsSinceEpoch(msg.timestamp, Qt::UTC).toString(Qt::ISODateWithMs) << "] "
                << msg.app << " ";
         if (!msg.category.isEmpty()) {
             stream << msg.category << " ";
